@@ -1,3 +1,6 @@
+from __future__ import absolute_import, division, print_function, unicode_literals
+
+
 class DiscogsAPIError(Exception):
     """Root Exception class for Discogs API errors."""
     pass
@@ -16,7 +19,14 @@ class HTTPError(DiscogsAPIError):
     """Exception class for HTTP errors."""
     def __init__(self, message, code):
         self.status_code = code
-        self.msg = '%d: %s' % (code, message)
+        self.msg = '{0}: {1}'.format(code, message)
 
     def __str__(self):
         return self.msg
+
+
+class AuthorizationError(HTTPError):
+    """The server rejected the client's credentials."""
+    def __init__(self, message, code, response):
+        super(AuthorizationError, self).__init__(message, code)
+        self.msg = '{0} Response: {1!r}'.format(self.msg, response)
